#ifndef _ISL_INCLUDE_ISL_STDINT_H
#define _ISL_INCLUDE_ISL_STDINT_H 1
#ifndef _GENERATED_STDINT_H
#define _GENERATED_STDINT_H "isl 0.22.1"
/* generated using gnu compiler powerpc64le-conda_cos7-linux-gnu-cc (crosstool-NG 1.23.0.449-a04d0) 7.3.0 */
#define _STDINT_HAVE_STDINT_H 1
#include <stdint.h>
#endif
#endif
